@@ -1,6 +1,6 @@
 (* camlp5r *)
-(* $Id: q_ast.ml,v 6.24 2011-02-17 10:20:50 deraugla Exp $ *)
-(* Copyright (c) INRIA 2007-2010 *)
+(* $Id: q_ast.ml,v 6.26 2011-05-21 13:22:20 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2011 *)
 
 #load "pa_macro.cmo";
 #load "pa_extend.cmo";
@@ -145,8 +145,8 @@ module Meta_make (C : MetaSig) =
           C.node "TyVrn"
             [C.vala (C.list poly_variant) lpv;
              C.option (C.option (C.vala (C.list C.string))) ools]
-      | TyXtr _ s ot →
-          C.node "TyXtr" [C.string s; C.option (C.vala ctyp) ot] ]
+      | 
+          TyXtr loc s _ → C.xtr loc s ]
     and poly_variant =
       fun
       [ PvTag _ s b lt →
@@ -187,8 +187,8 @@ module Meta_make (C : MetaSig) =
       | PaUnp _ s omt →
           C.node "PaUnp" [C.vala C.string s; C.option module_type omt]
       | PaVrn _ s → C.node "PaVrn" [C.vala C.string s]
-      | PaXtr _ s op →
-          C.node "PaXtr" [C.string s; C.option (C.vala patt) op] ]
+      | 
+          PaXtr loc s _ → C.xtr_or_anti loc (fun r → C.node "PaAnt" [r]) s ]
     and expr =
       fun
       [ ExAcc _ e1 e2 → C.node "ExAcc" [expr e1; expr e2]
@@ -269,8 +269,8 @@ module Meta_make (C : MetaSig) =
       | ExUid _ s → C.node "ExUid" [C.vala C.string s]
       | ExVrn _ s → C.node "ExVrn" [C.vala C.string s]
       | ExWhi _ e le → C.node "ExWhi" [expr e; C.vala (C.list expr) le]
-      | ExXtr _ s oe →
-          C.node "ExXtr" [C.string s; C.option (C.vala expr) oe] ]
+      | 
+          ExXtr loc s _ → C.xtr_or_anti loc (fun r → C.node "ExAnt" [r]) s ]
     and module_type =
       fun
       [ MtAcc _ mt1 mt2 → C.node "MtAcc" [module_type mt1; module_type mt2]
@@ -284,8 +284,8 @@ module Meta_make (C : MetaSig) =
       | MtUid _ s → C.node "MtUid" [C.vala C.string s]
       | MtWit _ mt lwc →
           C.node "MtWit" [module_type mt; C.vala (C.list with_constr) lwc]
-      | MtXtr _ s omt →
-          C.node "MtXtr" [C.string s; C.option (C.vala module_type) omt] ]
+      | 
+          MtXtr loc s _ → C.xtr loc s ]
     and sig_item =
       fun
       [ SgCls _ lcict →
@@ -317,8 +317,8 @@ module Meta_make (C : MetaSig) =
              C.vala (C.list (fun (si, _) → C.tuple [sig_item si; C.loc_v ()]))
                lsil]
       | SgVal _ s t → C.node "SgVal" [C.vala C.string s; ctyp t]
-      | SgXtr _ s osi →
-          C.node "SgXtr" [C.string s; C.option (C.vala sig_item) osi] ]
+      | 
+          SgXtr loc s _ → C.xtr loc s ]
     and with_constr =
       fun
       [ WcMod _ ls me →
@@ -343,8 +343,8 @@ module Meta_make (C : MetaSig) =
       | MeTyc _ me mt → C.node "MeTyc" [module_expr me; module_type mt]
       | MeUid _ s → C.node "MeUid" [C.vala C.string s]
       | MeUnp _ e omt → C.node "MeUnp" [expr e; C.option module_type omt]
-      | MeXtr _ s ome →
-          C.node "MeXtr" [C.string s; C.option (C.vala module_expr) ome] ]
+      | 
+          MeXtr loc s _ → C.xtr loc s ]
     and str_item =
       fun
       [ StCls _ lcice →
@@ -382,8 +382,8 @@ module Meta_make (C : MetaSig) =
           C.node "StVal"
             [C.vala C.bool b;
              C.vala (C.list (fun (p, e) → C.tuple [patt p; expr e])) lpe]
-      | StXtr _ s osi →
-          C.node "StXtr" [C.string s; C.option (C.vala str_item) osi] ]
+      | 
+          StXtr loc s _ → C.xtr loc s ]
     and type_decl x =
       C.record
         [(record_label "tdNam",
@@ -406,8 +406,8 @@ module Meta_make (C : MetaSig) =
       | CtSig _ ot lcsi →
           C.node "CtSig"
             [C.vala (C.option ctyp) ot; C.vala (C.list class_sig_item) lcsi]
-      | CtXtr _ s oct →
-          C.node "CtXtr" [C.string s; C.option (C.vala class_type) oct] ]
+      | 
+          CtXtr loc s _ → C.xtr loc s ]
     and class_sig_item =
       fun
       [ CgCtr _ t1 t2 → C.node "CgCtr" [ctyp t1; ctyp t2]
@@ -435,8 +435,8 @@ module Meta_make (C : MetaSig) =
           C.node "CeStr"
             [C.vala (C.option patt) op; C.vala (C.list class_str_item) lcsi]
       | CeTyc _ ce ct → C.node "CeTyc" [class_expr ce; class_type ct]
-      | CeXtr _ s oce →
-          C.node "CeXtr" [C.string s; C.option (C.vala class_expr) oce] ]
+      | 
+          CeXtr loc s _ → C.xtr loc s ]
     and class_str_item =
       fun
       [ CrCtr _ t1 t2 → C.node "CrCtr" [ctyp t1; ctyp t2]
